@@ -51,38 +51,53 @@ class Editor (hildon.TextView):
     if prefs.prefs_dict['hildon_text_completion']==False:
       self.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_FULL)
 
+    self.indent = prefs.prefs_dict['indent']
+    
     self.set_editable (True)
     self.no_edit_mode = True
     self.modify_font (pango.FontDescription (font_name+" "+str(font_size)))
     self.language = language
     self.searched_text = None
 
-#    self.connect("key-press-event", self.on_key_press)
-
-#TODO need fix
-#    self.connect("expose_event", self.line_numbers_expose)
+    if prefs.prefs_dict['show_lines'] == True:
+      self.set_border_window_size(gtk.TEXT_WINDOW_LEFT, 30)
+      self.line_view = self.get_window(gtk.TEXT_WINDOW_LEFT)
+      self.connect("expose_event", self.line_numbers_expose)
+  
 #  def on_key_press(self, widget, event, *args):
 #    #CTRL-S : save
 #    if (event.keyval == gtk.keysyms.s) and (event.state==gtk.gdk.CONTROL_MASK):
 #      self.save(self.filepath)
+
+  def get_lines(self, first_y, last_y, buffer_coords, numbers):
+    text_view = self
+    # Get iter at first y
+    iter, top = text_view.get_line_at_y(first_y)
+
+    # For each iter, get its location and add it to the arrays.
+    # Stop when we pass last_y
+    count = 0
+    size = 0
+
+    while not iter.is_end():
+      y, height = text_view.get_line_yrange(iter)
+      buffer_coords.append(y)
+      line_num = iter.get_line()
+      numbers.append(line_num)
+      count += 1
+      if (y + height) >= last_y:
+        break
+      iter.forward_line()
+
+    return count
       
   def line_numbers_expose(self, widget, event, user_data=None):
     text_view = widget
 
-    # See if this expose is on the line numbers window
-    left_win = text_view.get_window(gtk.TEXT_WINDOW_LEFT)
-    right_win = text_view.get_window(gtk.TEXT_WINDOW_RIGHT)
-
-    if event.window == left_win:
-        type = gtk.TEXT_WINDOW_LEFT
-        target = left_win
-    elif event.window == right_win:
-        type = gtk.TEXT_WINDOW_RIGHT
-        target = right_win
-    else:
-        print '_nieeee'
-        return False
-
+    type = gtk.TEXT_WINDOW_LEFT
+    target = text_view.get_window(gtk.TEXT_WINDOW_LEFT)
+    target.set_background(gtk.gdk.Color(0,0,60000))
+ 
     first_y = event.area.y
     last_y = first_y + event.area.height
 
@@ -92,13 +107,12 @@ class Editor (hildon.TextView):
     numbers = []
     pixels = []
     count = self.get_lines(first_y, last_y, pixels, numbers)
-
     # Draw fully internationalized numbers!
     layout = widget.create_pango_layout("")
 
     for i in range(count):
         x, pos = text_view.buffer_to_window_coords(type, 0, pixels[i])
-        str = "%d" % numbers[i]
+        str = '%d' % numbers[i]
         layout.set_text(str)
         widget.style.paint_layout(target, widget.state, False,
                                   None, widget, None, 2, pos + 2, layout)
@@ -244,7 +258,7 @@ class Editor (hildon.TextView):
   #############################################################################
   def indent_tab (self):
     buffer = self.get_buffer()
-    tabul=' ' * 2
+    tabul=self.indent
     if (buffer.get_selection_bounds()!=()):
       start,end=buffer.get_selection_bounds()
       for line in range(start.get_line(),end.get_line()+1):
@@ -265,8 +279,8 @@ class Editor (hildon.TextView):
         if c == '\t':
           buffer.delete(r,r)
         else:
-          e=buffer.get_iter_at_offset(r.get_offset()+ 2)
-          if (buffer.get_text(r,e)==' '* 2):
+          e=buffer.get_iter_at_offset(r.get_offset()+ len(self.indent))
+          if (buffer.get_text(r,e)==self.indent):
             buffer.delete(r,e)
     else:
       r = buffer.get_iter_at_line(buffer.get_iter_at_mark(buffer.get_insert()).get_line())
@@ -274,8 +288,8 @@ class Editor (hildon.TextView):
       if c == '\t':
         buffer.delete(r,r)
       else:
-        e=buffer.get_iter_at_offset(r.get_offset()+ 2)
-        if (buffer.get_text(r,e)==' '* 2):
+        e=buffer.get_iter_at_offset(r.get_offset()+ len(self.indent))
+        if (buffer.get_text(r,e)==self.indent):
           buffer.delete(r,e)
 
   #############################################################################
