@@ -19,15 +19,23 @@ import osso
 import pango
 from portrait import FremantleRotation
 import os
+import pge_preferences
 
 class Help(hildon.Window):
   def __init__(self,filepath=None,caller=None):
     hildon.Window.__init__ (self)
-    FremantleRotation('net.khertan.pygtkeditor',self)
+    self.prefs = pge_preferences.Prefs()
+    self.prefs.load()
+
+    if self.prefs.prefs_dict['auto_rotate']==True:
+      self.rotation = FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.AUTOMATIC)
+    else:
+      self.rotation = FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.NEVER)
     
     p = hildon.PannableArea()
     t = hildon.TextView()
     t.set_editable(False)
+    t.set_wrap_mode(gtk.WRAP_WORD)
     t.get_buffer().set_text(u"""PyGTKEditor is a source code editor, specially designed for Maemo Devices.
 
 Report bugs on http://bugs.maemo.org/
@@ -109,14 +117,13 @@ Roadmap :
 ◦ Fix Bug #7021
 
 • Version 3.0.3 :
-◦ Prefs : indent size
-◦ Prefs : font and text size
-◦ Welcome screen
+◦ Fix Help Bug
 
-• Version 3.1.0 :
+• Version 3.0.4 :
 ◦ Prefs : indent size
-◦ Prefs : font and text size
 ◦ Welcome screen
+◦ Recent Chooser Change
+◦ Prefs show lines numbers
 
 •Version 3.3.0 :
 ◦ Plugins
@@ -125,4 +132,4 @@ Roadmap :
     p.add(t)
     self.add(p)
     
-    self.show_all()
\ No newline at end of file
+    self.show_all()
