@@ -23,6 +23,7 @@ from subprocess import *
 import commands
 import gobject
 import pge_preferences
+import pge_recentchooser
 
 LANGUAGES = (('.R','R'),
             ('.ada','ada'),
@@ -71,9 +72,9 @@ class Window(hildon.Window):
     self.prefs.load()
 
     if self.prefs.prefs_dict['auto_rotate']==True:
-      FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.AUTOMATIC)
+      self.rotation = FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.AUTOMATIC)
     else:
-      FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.NEVER)
+      self.rotation = FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.NEVER)
     
     self.is_fullscreen = False
     
@@ -138,9 +139,11 @@ class Window(hildon.Window):
     self.prefs.load()
     #rotate
     if self.prefs.prefs_dict['auto_rotate']==True:
-      FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.AUTOMATIC)
+      self.rotation.set_mode(FremantleRotation.AUTOMATIC)
+#      FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.AUTOMATIC)
     else:
-      FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.NEVER)
+      self.rotation.set_mode(FremantleRotation.NEVER)
+#      FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.NEVER)
     #font / size
     self.code_editor.modify_font(pango.FontDescription (self.prefs.prefs_dict['font_name']+" "+str(self.prefs.prefs_dict['font_size'])))
     
@@ -251,6 +254,7 @@ class Window(hildon.Window):
       #fc =hildon.FileChooserDialog(self, gtk.FILE_CHOOSER_ACTION_OPEN,fsm)
       fc = gobject.new(hildon.FileChooserDialog, action=gtk.FILE_CHOOSER_ACTION_OPEN)
       fc.set_property('show-files',True)
+      fc.set_current_folder('/home/user/MyDocs/')
       #fsm.set_property('visible-columns',7)
       #fc.set_extension('py')
       if fc.run()==gtk.RESPONSE_OK:
@@ -262,7 +266,8 @@ class Window(hildon.Window):
 
   def save_as(self):
     fsm = hildon.FileSystemModel()
-    fc = hildon.FileChooserDialog(self, gtk.FILE_CHOOSER_ACTION_SAVE,fsm)
+#    fc = hildon.FileChooserDialog(self, gtk.FILE_CHOOSER_ACTION_SAVE,fsm)
+    fc = gobject.new(hildon.FileChooserDialog, action=gtk.FILE_CHOOSER_ACTION_SAVE)      
     fc.set_show_hidden(True)
     fc.set_do_overwrite_confirmation(False)
 
@@ -402,13 +407,16 @@ class Window(hildon.Window):
     if label == 'New':
       self._parent.create_window() 
     elif label=='Recent':
-       fc = gtk.RecentChooserDialog("Recent Documents", self, None,(gtk.STOCK_OPEN, gtk.RESPONSE_ACCEPT))
-       if fc.run()==gtk.RESPONSE_ACCEPT:                                    
-         filepath = fc.get_current_item().get_uri()[7::]
-         fc.destroy()                                                   
-         self._parent.create_window(filepath)   
-       else:
-         fc.destroy()
+      filepath = pge_recentchooser.Dialog().get()
+      if path!=None:
+        self._parent.create_window(filepath)
+#       fc = gtk.RecentChooserDialog("Recent Documents", self, None,(gtk.STOCK_OPEN, gtk.RESPONSE_ACCEPT))
+#       if fc.run()==gtk.RESPONSE_ACCEPT:                                    
+#         filepath = fc.get_current_item().get_uri()[7::]
+#         fc.destroy()                                                   
+#         self._parent.create_window(filepath)   
+#       else:
+#         fc.destroy()
     elif label=='About':
       self._parent.onAbout(self)
     elif label == 'Open':
